@@ -15,7 +15,7 @@
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2006 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id: Validate.php,v 1.46 2006/01/23 17:16:35 cellog Exp $
+ * @version    CVS: $Id: Validate.php,v 1.50 2006/09/25 05:12:21 cellog Exp $
  * @link       http://pear.php.net/package/PEAR
  * @since      File available since Release 1.4.0a1
  */
@@ -38,7 +38,7 @@ require_once 'PEAR/Validator/PECL.php';
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2006 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.4.9
+ * @version    Release: 1.5.0
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 1.4.0a1
  */
@@ -188,7 +188,8 @@ class PEAR_Validate
         if ($this->_packagexml->getPackagexmlVersion() == '1.0') {
             $this->validateState();
             $this->validateFilelist();
-        } elseif ($this->_packagexml->getPackagexmlVersion() == '2.0') {
+        } elseif ($this->_packagexml->getPackagexmlVersion() == '2.0' ||
+                  $this->_packagexml->getPackagexmlVersion() == '2.1') {
             $this->validateTime();
             $this->validateStability();
             $this->validateDeps();
@@ -207,7 +208,8 @@ class PEAR_Validate
     {
         if ($this->_state == PEAR_VALIDATE_PACKAGING ||
               $this->_state == PEAR_VALIDATE_NORMAL) {
-            if ($this->_packagexml->getPackagexmlVersion() == '2.0' &&
+            if (($this->_packagexml->getPackagexmlVersion() == '2.0' ||
+                 $this->_packagexml->getPackagexmlVersion() == '2.1') &&
                   $this->_packagexml->getExtends()) {
                 $version = $this->_packagexml->getVersion() . '';
                 $name = $this->_packagexml->getPackage();
@@ -445,17 +447,18 @@ class PEAR_Validate
     {
         if ($this->_state == PEAR_VALIDATE_NORMAL ||
               $this->_state == PEAR_VALIDATE_PACKAGING) {
-            if (!preg_match('/\d\d\d\d\-\d\d\-\d\d/',
-                  $this->_packagexml->getDate())) {
-                $this->_addFailure('date', 'invalid release date "' .
-                    $this->_packagexml->getDate() . '"');
-                return false;
-            }
-            if (strtotime($this->_packagexml->getDate()) == -1) {
+
+            if (!preg_match('/(\d\d\d\d)\-(\d\d)\-(\d\d)/',
+                  $this->_packagexml->getDate(), $res) ||
+                  count($res) < 4
+                  || !checkdate($res[2], $res[3], $res[1])
+                ) {
                 $this->_addFailure('date', 'invalid release date "' .
                     $this->_packagexml->getDate() . '"');
                 return false;
             }
+
+
             if ($this->_state == PEAR_VALIDATE_PACKAGING &&
                   $this->_packagexml->getDate() != date('Y-m-d')) {
                 $this->_addWarning('date', 'Release Date "' .
@@ -628,4 +631,4 @@ class PEAR_Validate
         return true;
     }
 }
-?>
\ No newline at end of file
+?>
