@@ -6,7 +6,7 @@
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        | 
-   | available at through the world-wide-web at                           |
+   | available through the world-wide-web at the following url:           |
    | http://www.zend.com/license/2_00.txt.                                |
    | If you did not receive a copy of the Zend license and are unable to  |
    | obtain it through the world-wide-web, please send a note to          |
@@ -92,7 +92,7 @@ ZEND_API void zend_highlight(zend_syntax_highlighter_ini *syntax_highlighter_ini
 	int token_type;
 	char *last_color = syntax_highlighter_ini->highlight_html;
 	char *next_color;
-	int in_string=0, post_heredoc = 0;
+	int in_string=0;
 
 	zend_printf("<code>");
 	zend_printf("<font color=\"%s\">\n", last_color);
@@ -148,14 +148,9 @@ ZEND_API void zend_highlight(zend_syntax_highlighter_ini *syntax_highlighter_ini
 		switch (token_type) {
 			case T_END_HEREDOC:
 				zend_html_puts(token.value.str.val, token.value.str.len TSRMLS_CC);
-				post_heredoc = 1;
 				break;
 			default:
 				zend_html_puts(LANG_SCNG(yy_text), LANG_SCNG(yy_leng) TSRMLS_CC);
-				if (post_heredoc) {
-					 zend_html_putc('\n');
-					 post_heredoc = 0;
-				}
 				break;
 		}
 
@@ -203,18 +198,17 @@ ZEND_API void zend_strip(TSRMLS_D)
 				token.type = 0;
 				continue;
 			
-			case T_END_HEREDOC: {
-					char *ptr = LANG_SCNG(yy_text);
-
-					fwrite(ptr, LANG_SCNG(yy_leng) - 1, 1, stdout);
-					/* The ensure that we only write one ; and that it followed by the required newline */
-					putchar('\n');
-					if (ptr[LANG_SCNG(yy_leng) - 1] == ';') {
-						lex_scan(&token TSRMLS_CC);
-					}
-					efree(token.value.str.val);
-				}
-				break;
+			case T_END_HEREDOC:
+				zend_write(LANG_SCNG(yy_text), LANG_SCNG(yy_leng));
+				efree(token.value.str.val);
+				/* read the following character, either newline or ; */
+				if (lex_scan(&token TSRMLS_CC) != T_WHITESPACE) {
+					zend_write(LANG_SCNG(yy_text), LANG_SCNG(yy_leng));
+  				}
+				zend_write("\n", sizeof("\n") - 1);
+				prev_space = 1;
+				token.type = 0;
+				continue;
 			
 			default:
 				fwrite(LANG_SCNG(yy_text), LANG_SCNG(yy_leng), 1, stdout);
