@@ -1,7 +1,5 @@
 #if PHP_WIN32
 #include "../../../../main/config.w32.h"
-#elif defined(NETWARE)
-#include "config.nw.h"
 #else
 #include <php_config.h>
 #endif
