@@ -2,26 +2,26 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
    | dbx module version 1.0                                               |
    +----------------------------------------------------------------------+
    | Copyright (c) 2001 Guidance Rotterdam BV                             |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
    | Author : Marc Boeren         <marc@guidance.nl>                      |
-   |          Frank M. Kromann    <frank@frontbase.com>                   |
+   |          Frank M. Kromann    <frank@kromann.info>                    |
    +----------------------------------------------------------------------+
 */
 
-/* $Id: dbx_fbsql.c,v 1.9 2002/10/30 15:03:00 mboeren Exp $ */
+/* $Id: dbx_fbsql.c,v 1.9.2.2.6.3 2007/12/31 07:22:46 sebastian Exp $ */
 
 #include "dbx.h"
 #include "dbx_fbsql.h"
