@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2006 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: ftp.h,v 1.30.2.3.4.1 2006/01/01 13:46:52 sniper Exp $ */
+/* $Id: ftp.h,v 1.30.2.3.4.4 2007/12/31 07:22:47 sebastian Exp $ */
 
 #ifndef	FTP_H
 #define	FTP_H
@@ -39,7 +39,7 @@
 #define	FTP_BUFSIZE	4096
 
 typedef enum ftptype {
-	FTPTYPE_ASCII,
+	FTPTYPE_ASCII=1,
 	FTPTYPE_IMAGE
 } ftptype_t;
 
