@@ -2,12 +2,12 @@
   +----------------------------------------------------------------------+
   | PHP Version 4                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2003 The PHP Group                                |
+  | Copyright (c) 1997-2008 The PHP Group                                |
   +----------------------------------------------------------------------+
-  | This source file is subject to version 2.02 of the PHP license,      |
+  | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
-  | available at through the world-wide-web at                           |
-  | http://www.php.net/license/2_02.txt.                                 |
+  | available through the world-wide-web at the following url:           |
+  | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
@@ -15,7 +15,7 @@
   | Author: Hartmut Holzgraefe  <hholzgra@php.net>                       |
   +----------------------------------------------------------------------+
 
-  $Id: mime_magic.c,v 1.13.2.12 2004/01/15 06:09:43 sniper Exp $ 
+  $Id: mime_magic.c,v 1.13.2.13.2.4 2007/12/31 07:22:49 sebastian Exp $ 
 
   This module contains a lot of stuff taken from Apache mod_mime_magic,
   so the license section is a little bit longer than usual:
@@ -314,7 +314,7 @@ PHP_FUNCTION(mime_content_type)
 	}
 
 	if (conf->magic == (struct magic *)-1) {
-		php_error(E_ERROR, MODNAME " could not be initialized, magic file %s is not avaliable",  conf->magicfile);
+		php_error(E_ERROR, MODNAME " could not be initialized, magic file %s is not available",  conf->magicfile);
 		RETURN_FALSE;
 	} 
 
@@ -651,9 +651,7 @@ static int parse(char *l, int lineno)
     }
     else
 		m->nospflag = 0;
-    strncpy(m->desc, l, sizeof(m->desc) - 1);
-    m->desc[sizeof(m->desc) - 1] = '\0';
-
+    strlcpy(m->desc, l, sizeof(m->desc));
     return 0;
 }
 
