@@ -5,7 +5,7 @@ This file is public domain and comes with NO WARRANTY of any kind */
 
 #include <global.h>
 #include <m_string.h>
-#if !defined(HAVE_STRTOULL) && defined(HAVE_LONG_LONG)
-#define MYSQL_LONGLONG
+#if !defined(HAVE_STRTOLL) && defined(HAVE_LONG_LONG)
+#define USE_LONGLONG
 #include "strto.c"
 #endif
