@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2006 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: basic_functions.c,v 1.543.2.51.2.10 2006/06/28 22:09:09 iliaa Exp $ */
+/* $Id: basic_functions.c,v 1.543.2.51.2.14 2007/12/31 07:22:51 sebastian Exp $ */
 
 #include "php.h"
 #include "php_streams.h"
@@ -1227,6 +1227,7 @@ PHP_RSHUTDOWN_FUNCTION(basic)
 		setlocale(LC_CTYPE, "");
 	}
 	STR_FREE(BG(locale_string));
+	BG(locale_string) = NULL;
 
 	/*
 	 FG(stream_wrappers) are destroyed
@@ -3037,24 +3038,25 @@ static int copy_request_variable(void *pDest, int num_args, va_list args, zend_h
 	prefix = va_arg(args, char *);
 	prefix_len = va_arg(args, uint);
 
-	if (!prefix_len) {
-		if (!hash_key->nKeyLength) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Numeric key detected - possible security hazard.");
-			return 0;
-		} else if (!strcmp(hash_key->arKey, "GLOBALS")) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Attempted GLOBALS variable overwrite.");
-			return 0; 
-		}
+	if (!prefix_len && !hash_key->nKeyLength) {
+		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Numeric key detected - possible security hazard.");
+		return 0;
 	}
 
 	if (hash_key->nKeyLength) {
 		new_key_len = prefix_len + hash_key->nKeyLength;
-		new_key = (char *) emalloc(new_key_len);
+		new_key = (char *) emalloc(new_key_len); /* +1 comes from nKeyLength */
 
 		memcpy(new_key, prefix, prefix_len);
 		memcpy(new_key+prefix_len, hash_key->arKey, hash_key->nKeyLength);
 	} else {
 		new_key_len = spprintf(&new_key, 0, "%s%ld", prefix, hash_key->h);
+		new_key_len++;
+	}
+
+	if (php_varname_check(new_key, new_key_len, 0 TSRMLS_CC) == FAILURE) {
+		efree(new_key);
+		return 0;
 	}
 
 	zend_hash_del(&EG(symbol_table), new_key, new_key_len);
