@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2006 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: credits.c,v 1.21.2.6.2.3 2006/01/01 13:46:57 sniper Exp $ */
+/* $Id: credits.c,v 1.21.2.6.2.7 2007/12/31 07:22:52 sebastian Exp $ */
 
 #include "php.h"
 #include "info.h"
@@ -98,7 +98,7 @@ PHPAPI void php_print_credits(int flag)
 		php_info_print_table_start();
 		php_info_print_table_colspan_header(2, "PHP Documentation");
 		CREDIT_LINE("Authors", "Mehdi Achour, Friedhelm Betz, Antony Dovgal, Nuno Lopes, Philip Olson, Georg Richter, Damien Seguy, Jakub Vrana");
-		CREDIT_LINE("Editor", "Gabor Hojtsy");
+		CREDIT_LINE("Editor", "Philip Olson");
 		CREDIT_LINE("User Note Maintainers", "Mehdi Achour, Friedhelm Betz, Vincent Gevers, Aidan Lister, Nuno Lopes, Tom Sommer");
 		CREDIT_LINE("Other Contributors", "Previously active authors, editors and other contributors are listed in the manual.");
 		php_info_print_table_end();
@@ -115,7 +115,7 @@ PHPAPI void php_print_credits(int flag)
 		/* Website Team */
 		php_info_print_table_start();
 		php_info_print_table_header(1, "PHP Website Team");
-		php_info_print_table_row(1, "Gabor Hojtsy, Colin Viebrock, Jim Winstead");
+		php_info_print_table_row(1, "Hannes Magnusson, Colin Viebrock, Jim Winstead");
 		php_info_print_table_end();
 	}
 
