@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -18,7 +18,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: dl.c,v 1.79.2.1 2002/12/05 21:09:18 helly Exp $ */
+/* $Id: dl.c,v 1.79.2.3.8.5 2007/12/31 07:22:52 sebastian Exp $ */
 
 #include "php.h"
 #include "dl.h"
@@ -40,11 +40,7 @@
 #include "win32/winutil.h"
 #define GET_DL_ERROR()	php_win_err()
 #elif defined(NETWARE)
-#ifdef NEW_LIBC
 #include <sys/param.h>
-#else
-#include "netware/param.h"
-#endif
 #define GET_DL_ERROR()	dlerror()
 #else
 #include <sys/param.h>
@@ -61,7 +57,9 @@ PHP_FUNCTION(dl)
 	pval **file;
 
 #ifdef ZTS
-	if ((strncmp(sapi_module.name, "cgi", 3)!=0) && (strcmp(sapi_module.name, "cli")!=0)) {
+	if ((strncmp(sapi_module.name, "cgi", 3)!=0) && 
+		(strcmp(sapi_module.name, "cli")!=0) &&
+		(strncmp(sapi_module.name, "embed", 5)!=0)) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Not supported in multithreaded Web servers - use extension statements in your php.ini");
 		RETURN_FALSE;
 	}
@@ -145,7 +143,6 @@ void php_dl(pval *file, int type, pval *return_value TSRMLS_DC)
 
 	efree(libpath);
 
-#ifndef NETWARE
 	get_module = (zend_module_entry *(*)(void)) DL_FETCH_SYMBOL(handle, "get_module");
 
 	/*
@@ -156,23 +153,6 @@ void php_dl(pval *file, int type, pval *return_value TSRMLS_DC)
 
 	if (!get_module)
 		get_module = (zend_module_entry *(*)(void)) DL_FETCH_SYMBOL(handle, "_get_module");
-#else
-	/* NetWare doesn't support two NLMs exporting same symbol */
-	{
-		char symbol_name[64] = "\0";
-		int module_name_length = Z_STRLEN_P(file) - 4;  /* '.nlm' is 4 characters; knock it off */
-
-		/* Take the module name (e.g.: 'php_ldap') and append '@get_module' to it */
-		strncpy(symbol_name, Z_STRVAL_P(file), module_name_length);
-		symbol_name[module_name_length] = '\0';
-		strcat(symbol_name, "@");
-		strcat(symbol_name, "get_module");
-
-		get_module = (zend_module_entry *(*)(void)) DL_FETCH_SYMBOL(handle, symbol_name);
-	}
-	/* NetWare doesn't prepend '_' to symbol names; so the corresponding portion of code is also
-	   not required for NetWare */
-#endif
 
 	if (!get_module) {
 		DL_UNLOAD(handle);
