@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -15,7 +15,7 @@
    | Author: Chris Schneider <cschneid@relog.ch>                          |
    +----------------------------------------------------------------------+
  */
-/* $Id: pack.c,v 1.40.2.7 2005/01/25 22:52:19 iliaa Exp $ */
+/* $Id: pack.c,v 1.40.2.7.2.8 2007/12/31 07:22:52 sebastian Exp $ */
 
 #include "php.h"
 
@@ -32,17 +32,12 @@
 #include "win32/param.h"
 #elif defined(NETWARE)
 #ifdef USE_WINSOCK
-/*#include <ws2nlm.h>*/
 #include <novsock2.h>
 #else
 #include <sys/socket.h>
 #endif
-#ifdef NEW_LIBC
 #include <sys/param.h>
 #else
-#include "netware/param.h"
-#endif
-#else
 #include <sys/param.h>
 #endif
 #include "ext/standard/head.h"
@@ -52,8 +47,6 @@
 #if HAVE_PWD_H
 #ifdef PHP_WIN32
 #include "win32/pwd.h"
-#elif defined(NETWARE)
-#include "netware/pwd.h"
 #else
 #include <pwd.h>
 #endif
@@ -253,7 +246,7 @@ PHP_FUNCTION(pack)
 		switch ((int) code) {
 			case 'h': 
 			case 'H': 
-				INC_OUTPUTPOS((arg + 1) / 2,1)	/* 4 bit per arg */
+				INC_OUTPUTPOS((arg + (arg % 2)) / 2,1)	/* 4 bit per arg */
 				break;
 
 			case 'a': 
@@ -546,7 +539,7 @@ PHP_FUNCTION(unpack)
 	while (formatlen-- > 0) {
 		char type = *(format++);
 		char c;
-		int arg = 1;
+		int arg = 1, argb;
 		char *name;
 		int namelen;
 		int size=0;
@@ -571,6 +564,7 @@ PHP_FUNCTION(unpack)
 
 		/* Get of new value in array */
 		name = format;
+		argb = arg;
 
 		while (formatlen > 0 && *format != '/') {
 			formatlen--;
@@ -600,7 +594,7 @@ PHP_FUNCTION(unpack)
 
 			case 'h': 
 			case 'H': 
-				size = (arg > 0) ? arg / 2 : arg;
+				size = (arg > 0) ? (arg + (arg % 2)) / 2 : arg;
 				arg = 1;
 				break;
 
@@ -642,6 +636,12 @@ PHP_FUNCTION(unpack)
 			case 'd':
 				size = sizeof(double);
 				break;
+
+			default:
+				php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid format type %c", type);
+				zval_dtor(return_value);
+				RETURN_FALSE;
+				break;
 		}
 
 		/* Do actual unpacking */
@@ -699,6 +699,10 @@ PHP_FUNCTION(unpack)
 							len = size * 2;
 						} 
 
+						if (argb > 0) {	
+							len -= argb % 2;
+						}
+
 						buf = emalloc(len + 1);
 
 						for (ipos = opos = 0; opos < len; opos++) {
