@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
  
-/* $Id: sysvshm.c,v 1.56.8.6 2005/01/23 20:17:27 iliaa Exp $ */
+/* $Id: sysvshm.c,v 1.56.8.6.2.4 2007/12/31 07:22:53 sebastian Exp $ */
 
 /* This has been built and tested on Linux 2.2.14 
  *
@@ -213,7 +213,7 @@ PHP_FUNCTION(shm_remove)
 
 	shm_list_ptr = (sysvshm_shm *) zend_list_find(id, &type);
 
-	if (!shm_list_ptr) {
+	if (!shm_list_ptr || type != php_sysvshm.le_shm) {
 		php_error(E_WARNING, "The parameter is not a valid shm_identifier");
 		RETURN_FALSE;
 	}
@@ -224,7 +224,7 @@ PHP_FUNCTION(shm_remove)
 	} 
 
 	RETURN_TRUE;
-}
+} 
 /* }}} */
 
 /* {{{ proto int shm_put_var(int shm_identifier, int variable_key, mixed variable)
@@ -249,7 +249,7 @@ PHP_FUNCTION(shm_put_var)
 	key = Z_LVAL_PP(arg_key);
 
 	shm_list_ptr = (sysvshm_shm *) zend_list_find(id, &type);
-	if (type!=php_sysvshm.le_shm) {
+	if (!shm_list_ptr || type != php_sysvshm.le_shm) {
 		php_error(E_WARNING, "%ld is not a SysV shared memory index", id);
 		RETURN_FALSE;
 	}
@@ -296,7 +296,7 @@ PHP_FUNCTION(shm_get_var)
 	key = Z_LVAL_PP(arg_key);
 
 	shm_list_ptr = (sysvshm_shm *) zend_list_find(id, &type);
-	if (type!=php_sysvshm.le_shm) {
+	if (!shm_list_ptr || type != php_sysvshm.le_shm) {
 		php_error(E_WARNING, "%ld is not a SysV shared memory index", id);
 		RETURN_FALSE;
 	}
@@ -342,7 +342,7 @@ PHP_FUNCTION(shm_remove_var)
 	key = Z_LVAL_PP(arg_key);
 
 	shm_list_ptr = (sysvshm_shm *) zend_list_find(id, &type);
-	if (type!=php_sysvshm.le_shm) {
+	if (!shm_list_ptr || type != php_sysvshm.le_shm) {
 		php_error(E_WARNING, "%ld is not a SysV shared memory index", id);
 		RETURN_FALSE;
 	}
