@@ -2,12 +2,12 @@
 	+----------------------------------------------------------------------+
 	| PHP Version 4                                                        |
 	+----------------------------------------------------------------------+
-	| Copyright (c) 1997-2003 The PHP Group                                |
+	| Copyright (c) 1997-2008 The PHP Group                                |
 	+----------------------------------------------------------------------+
-	| This source file is subject to version 2.02 of the PHP license,      |
+	| This source file is subject to version 3.01 of the PHP license,      |
 	| that is bundled with this package in the file LICENSE, and is        |
-	| available at through the world-wide-web at                           |
-	| http://www.php.net/license/2_02.txt.                                 |
+	| available through the world-wide-web at the following url:           |
+	| http://www.php.net/license/3_01.txt                                  |
 	| If you did not receive a copy of the PHP license and are unable to   |
 	| obtain it through the world-wide-web, please send a note to          |
 	| license@php.net so we can mail you a copy immediately.               |
@@ -16,7 +16,7 @@
 	|          Zeev Suraski <zeev@zend.com>                                |
 	+----------------------------------------------------------------------+
 
-	$Id: internal_functions_win32.c,v 1.65.2.3 2003/08/26 02:51:21 sniper Exp $
+	$Id: internal_functions_win32.c,v 1.65.2.3.4.3 2007/12/31 07:22:54 sebastian Exp $
 */
 
 /* {{{ includes
