@@ -3,23 +3,53 @@
 
 #ifdef PHP_WIN32
 #include "config.w32.h"
-#elif defined(NETWARE)
-#include "config.nw.h"
 #else
 #include <php_config.h>
 #endif
 
 #if defined(HAVE_BUNDLED_PCRE) || !defined(PHP_VERSION)
 #define pcre_compile 			php_pcre_compile
+#define pcre_compile2 			php_pcre_compile2
 #define pcre_copy_substring		php_pcre_copy_substring
 #define pcre_exec				php_pcre_exec
-#define pcre_get_substring		php_pcre_substring
+#define pcre_get_substring		php_pcre_get_substring
 #define pcre_get_substring_list	php_pcre_get_substring_list
 #define pcre_info				php_pcre_info
 #define pcre_maketables			php_pcre_maketables
 #define pcre_study				php_pcre_study
 #define pcre_version			php_pcre_version
 #define pcre_fullinfo			php_pcre_fullinfo
+#define pcre_free				php_pcre_free
+#define pcre_malloc				php_pcre_malloc
+#define pcre_config				php_pcre_config
+#define pcre_copy_named_substring php_pcre_copy_named_substring
+#define pcre_free_substring 	php_pcre_free_substring
+#define pcre_free_substring_list php_pcre_free_substring_list
+#define pcre_get_named_substring php_pcre_get_named_substring
+#define pcre_get_stringnumber 	php_pcre_get_stringnumber
+#define pcre_refcount 			php_pcre_refcount
+#define _pcre_ord2utf8 			php__pcre_ord2utf8
+#define _pcre_try_flipped 		php__pcre_try_flipped
+#define _pcre_ucp_findprop 		php__pcre_ucp_findprop
+#define _pcre_ucp_othercase 	php__pcre_ucp_othercase
+#define _pcre_valid_utf8 		php__pcre_valid_utf8
+#define _pcre_xclass	 		php__pcre_xclass
+#define pcre_callout			php_pcre_callout
+#define _pcre_OP_lengths		php__pcre_OP_lengths
+#define _pcre_utt_names			php__pcre_utt_names
+#define _pcre_default_tables		php__pcre_default_tables
+#define pcre_get_stringtable_entries	php_pcre_get_stringtable_entries
+#define _pcre_is_newline		php__pcre_is_newline
+#define pcre_stack_free			php_pcre_stack_free
+#define pcre_stack_malloc		php_pcre_stack_malloc
+#define _pcre_utf8_table1		php__pcre_utf8_table1
+#define _pcre_utf8_table1_size		php__pcre_utf8_table1_size
+#define _pcre_utf8_table2		php__pcre_utf8_table2
+#define _pcre_utf8_table3		php__pcre_utf8_table3
+#define _pcre_utf8_table4		php__pcre_utf8_table4
+#define _pcre_utt			php__pcre_utt
+#define _pcre_utt_size			php__pcre_utt_size
+#define _pcre_was_newline		php__pcre_was_newline
 #endif
 
 #define lookup				php_lookup
