@@ -3,12 +3,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -33,7 +33,7 @@
 
 /*
  * TODO:
- * - do not test PEAR components if base class and/or component class cannot be instanciated
+ * - do not test PEAR components if base class and/or component class cannot be instantiated
  */
 
 
@@ -57,6 +57,9 @@ NO_PCRE_ERROR;
 exit;
 }
 
+// store current directory
+$CUR_DIR = getcwd();
+
 // change into the PHP source directory.
 
 if (getenv('TEST_PHP_SRCDIR')) {
@@ -375,7 +378,7 @@ if (!getenv('NO_INTERACTION')) {
 		
 		/* Ask the user to provide an email address, so that QA team can contact the user */
 		if (!strncasecmp($user_input, 'y', 1) || strlen(trim($user_input)) == 0) {
-			echo "\nPlease enter your email address.\n(You address will be mangled so that it will not go out on any\nmailinglist in plain text): ";
+			echo "\nPlease enter your email address.\n(Your address will be mangled so that it will not go out on any\nmailinglist in plain text): ";
 			flush();
 			$fp = fopen("php://stdin", "r+");
 			$user_email = trim(fgets($fp, 1024));
@@ -407,8 +410,10 @@ if (!getenv('NO_INTERACTION')) {
 		if (substr(PHP_OS, 0, 3) != "WIN") {
 			$automake = shell_exec('automake --version');
 			$autoconf = shell_exec('autoconf --version');
+
 			/* Always use the generated libtool - Mac OSX uses 'glibtool' */
-			$libtool = shell_exec('./libtool --version');
+			$libtool = shell_exec($CUR_DIR . '/libtool --version');
+
 			/* Try the most common flags for 'version' */
 			$flags = array('-v', '-V', '--version');
 			$cc_status=0;
@@ -419,13 +424,13 @@ if (!getenv('NO_INTERACTION')) {
 					break;
 				}
 			}
-			$ldd = shell_exec("ldd $php");
+			$ldd = shell_exec("ldd $php 2>/dev/null");
 		}
 		$failed_tests_data .= "Automake:\n$automake\n";
 		$failed_tests_data .= "Autoconf:\n$autoconf\n";
 		$failed_tests_data .= "Libtool:\n$libtool\n";
 		$failed_tests_data .= "Compiler:\n$compiler\n";
-		$failed_tests_data .= "Bison:\n". @shell_exec('bison --version'). "\n";
+		$failed_tests_data .= "Bison:\n". @shell_exec('bison --version 2>/dev/null'). "\n";
 		$failed_tests_data .= "Libraries:\n$ldd\n";
 		$failed_tests_data .= "\n";
 		
@@ -439,7 +444,7 @@ if (!getenv('NO_INTERACTION')) {
 		$compression = 0;
 		
 		if ($just_save_results || !mail_qa_team($failed_tests_data, $compression, $status)) {
-			$output_file = 'php_test_results_' . date('Ymd') . ( $compression ? '.txt.gz' : '.txt' );
+			$output_file = $CUR_DIR . '/php_test_results_' . date('Ymd_Hi') . ( $compression ? '.txt.gz' : '.txt' );
 			$fp = fopen($output_file, "w");
 			fwrite($fp, $failed_tests_data);
 			fclose($fp);
