@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -18,7 +18,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: sapi_apache2.c,v 1.91.2.27 2005/04/08 20:35:02 sniper Exp $ */
+/* $Id: sapi_apache2.c,v 1.91.2.27.2.4 2007/12/31 07:22:55 sebastian Exp $ */
 
 #include <fcntl.h>
 
@@ -168,9 +168,15 @@ php_apache_sapi_get_stat(TSRMLS_D)
 	ctx->finfo.st_gid = ctx->r->finfo.group;
 	ctx->finfo.st_dev = ctx->r->finfo.device;
 	ctx->finfo.st_ino = ctx->r->finfo.inode;
+#ifdef NETWARE
+	ctx->finfo.st_atime.tv_sec = ctx->r->finfo.atime/1000000;
+	ctx->finfo.st_mtime.tv_sec = ctx->r->finfo.mtime/1000000;
+	ctx->finfo.st_ctime.tv_sec = ctx->r->finfo.ctime/1000000;
+#else
 	ctx->finfo.st_atime = ctx->r->finfo.atime/1000000;
 	ctx->finfo.st_mtime = ctx->r->finfo.mtime/1000000;
 	ctx->finfo.st_ctime = ctx->r->finfo.ctime/1000000;
+#endif
 	ctx->finfo.st_size = ctx->r->finfo.size;
 	ctx->finfo.st_nlink = ctx->r->finfo.nlink;
 
