@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -20,7 +20,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: cgi_main.c,v 1.190.2.68 2005/04/28 14:24:47 sniper Exp $ */
+/* $Id: cgi_main.c,v 1.190.2.68.2.9 2007/12/31 07:22:55 sebastian Exp $ */
 
 #include "php.h"
 #include "php_globals.h"
@@ -281,7 +281,7 @@ static void sapi_cgibin_flush(void *server_context)
 #ifndef PHP_WIN32
 		!parent && 
 #endif
-		(!request || FCGX_FFlush(request->out) == -1)) {
+		request && FCGX_FFlush(request->out) == -1) {
 			php_handle_aborted_connection();
 		}
 		return;
@@ -335,20 +335,12 @@ static int sapi_cgi_send_headers(sapi_headers_struct *sapi_headers TSRMLS_DC)
 		PHPWRITE_H(buf, len);
 	}
 
-	if (SG(sapi_headers).send_default_content_type) {
-		char *hd;
-
-		hd = sapi_get_default_content_type(TSRMLS_C);
-		PHPWRITE_H("Content-type: ", sizeof("Content-type: ")-1);
-		PHPWRITE_H(hd, strlen(hd));
-		PHPWRITE_H("\r\n", 2);
-		efree(hd);
-	}
-	
 	h = zend_llist_get_first_ex(&sapi_headers->headers, &pos);
-    while (h) {
-		PHPWRITE_H(h->header, h->header_len);
-		PHPWRITE_H("\r\n", 2);
+	while (h) {
+		if (h->header_len) {
+			PHPWRITE_H(h->header, h->header_len);
+			PHPWRITE_H("\r\n", 2);
+		}
 		h = zend_llist_get_next_ex(&sapi_headers->headers, &pos);
 	}
 	PHPWRITE_H("\r\n", 2);
@@ -359,18 +351,14 @@ static int sapi_cgi_send_headers(sapi_headers_struct *sapi_headers TSRMLS_DC)
 
 static int sapi_cgi_read_post(char *buffer, uint count_bytes TSRMLS_DC)
 {
-	uint read_bytes=0, tmp_read_bytes;
-#if PHP_FASTCGI
-	char *pos = buffer;
-#endif
+	int read_bytes=0, tmp_read_bytes;
 
 	count_bytes = MIN(count_bytes, (uint)SG(request_info).content_length-SG(read_post_bytes));
 	while (read_bytes < count_bytes) {
 #if PHP_FASTCGI
 		if (!FCGX_IsCGI()) {
 			FCGX_Request *request = (FCGX_Request *)SG(server_context);
-			tmp_read_bytes = FCGX_GetStr( pos, count_bytes-read_bytes, request->in );
-			pos += tmp_read_bytes;
+			tmp_read_bytes = FCGX_GetStr(buffer+read_bytes, count_bytes-read_bytes, request->in );
 		} else {
 			tmp_read_bytes = read(0, buffer+read_bytes, count_bytes-read_bytes);
 		}
@@ -491,7 +479,9 @@ static void sapi_cgi_log_message(char *message)
                                                                                                         
 	if (!FCGX_IsCGI() && logging) {
 		FCGX_Request *request = (FCGX_Request *)SG(server_context);
-		FCGX_FPrintF( request->err, "%s\n", message );
+		if (request) {
+			FCGX_FPrintF( request->err, "%s\n", message );
+		}
 		/* ignore return code */
 	} else
 #endif /* PHP_FASTCGI */
@@ -817,7 +807,7 @@ static void init_request_info(TSRMLS_D)
 							int l = strlen(env_document_root);
 							int path_translated_len = 0;
 							char *path_translated = NULL;
-							if (env_document_root[l-1]=='/') {
+							if (l && env_document_root[l-1]=='/') {
 								--l;
 							}
 
@@ -1268,7 +1258,8 @@ consult the installation file that came with this distribution, or visit \n\
 				fprintf( stderr, "Wait for kids, pid %d\n",
 					 getpid() );
 #endif
-				wait( &status );
+				while (wait( &status ) < 0) {
+				}
 				running--;
 			}
 		}
@@ -1395,7 +1386,7 @@ consult the installation file that came with this distribution, or visit \n\
 						}
 						php_print_info(0xFFFFFFFF TSRMLS_CC);
 						php_end_ob_buffers(1 TSRMLS_CC);
-						exit(1);
+						exit(0);
 						break;
 
   				case 'l': /* syntax check mode */
@@ -1413,7 +1404,7 @@ consult the installation file that came with this distribution, or visit \n\
 					print_extensions(TSRMLS_C);
 					php_printf("\n");
 					php_end_ob_buffers(1 TSRMLS_CC);
-					exit(1);
+					exit(0);
 					break;
 
 #if 0 /* not yet operational, see also below ... */
@@ -1441,12 +1432,12 @@ consult the installation file that came with this distribution, or visit \n\
 							SG(request_info).no_headers = 1;
 						}
 #if ZEND_DEBUG
-						php_printf("PHP %s (%s) (built: %s %s) (DEBUG)\nCopyright (c) 1997-2004 The PHP Group\n%s", PHP_VERSION, sapi_module.name, __DATE__, __TIME__, get_zend_version());
+						php_printf("PHP %s (%s) (built: %s %s) (DEBUG)\nCopyright (c) 1997-2008 The PHP Group\n%s", PHP_VERSION, sapi_module.name, __DATE__, __TIME__, get_zend_version());
 #else
-						php_printf("PHP %s (%s) (built: %s %s)\nCopyright (c) 1997-2004 The PHP Group\n%s", PHP_VERSION, sapi_module.name, __DATE__, __TIME__, get_zend_version());
+						php_printf("PHP %s (%s) (built: %s %s)\nCopyright (c) 1997-2008 The PHP Group\n%s", PHP_VERSION, sapi_module.name, __DATE__, __TIME__, get_zend_version());
 #endif
 						php_end_ob_buffers(1 TSRMLS_CC);
-						exit(1);
+						exit(0);
 						break;
 
   				case 'w': 
@@ -1696,6 +1687,7 @@ fastcgi_request_done:
 		exit_status = 255;
 	} zend_end_try();
 
+	SG(server_context) = NULL;
 	php_module_shutdown(TSRMLS_C);
 
 #ifdef ZTS
