@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -71,11 +71,6 @@ typedef struct {
 
 extern zend_module_entry java_module_entry;
 
-static zend_module_entry *additional_php_extensions[] = {
-  &java_module_entry
-};
-
-#define EXTCOUNT (sizeof(additional_php_extensions)/sizeof(zend_module_entry *))
 
 /***************************************************************************/
 
@@ -115,7 +110,7 @@ void ThrowServletException (JNIEnv *jenv, char *msg) {
 static int sapi_servlet_ub_write(const char *str, uint str_length TSRMLS_DC)
 {
 	if (!SG(server_context)) {
-		fprintf(stderr, str);
+		fprintf(stderr, "%s", str);
 		return 0;
 	}
 
@@ -261,7 +256,7 @@ JNIEXPORT void JNICALL Java_net_php_servlet_startup
 
 	sapi_startup(&servlet_sapi_module);
 
-	if (php_module_startup(&servlet_sapi_module, additional_php_extensions, EXTCOUNT)==FAILURE) {
+	if (php_module_startup(&servlet_sapi_module, &java_module_entry, 1)==FAILURE) {
 		ThrowServletException(jenv,"module startup failure");
 		return;
 	}
@@ -315,7 +310,7 @@ JNIEXPORT void JNICALL Java_net_php_servlet_send
 	 jstring contentType, jint contentLength, 
 	 jstring authUser, jboolean display_source_mode)
 {
-	zend_file_handle file_handle;
+	zend_file_handle file_handle = {0};
 	int retval;
 #ifndef VIRTUAL_DIR
 	char cwd[MAXPATHLEN];
